==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Utworzyć arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Utwórz nowy arkusz kalkulacyjny</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Wyrównaj do dołu</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Wyrównaj do dołu zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Wyrównaj do środka</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Wyrównaj do środka zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Wyrównaj do lewej</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Wyrównaj do lewej zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Wyrównaj do prawej</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Wyrównaj do prawej zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Wyrównaj do góry</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Wyrównaj do góry zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Wyrównaj do środka pionowo</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuj arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuj arkusz kalkulacyjny do pliku CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuj arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuj plik CSV do arkusza</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Scal komórki</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Scal wybrane komórki w arkuszu kalkulacyjnym</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Ustaw alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Ustaw alias dla wybranej komórki</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Podziel komórkę</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Rozdziel uprzednio scalone komórki w arkuszu kalkulacyjnym</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Tekst pogrubiony</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Ustaw pogrubiony tekst w zaznaczonych komórkach</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Kursywa</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Ustaw kursywę w zaznaczonych komórkach</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Podkreśl tekst</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Kolor użytkownika</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Właściwości komórki</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Kolor</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekst</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Tło</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>Wyrów&amp;nanie</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Pozioma</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Lewa</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Środek</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Prawo</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Pionowa</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Góra</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>U dołu</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Styl</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Pogrubienie</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Kursywa</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Podkreślenie</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Wyświetl jednostkę</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Ciąg jednostek</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias dla tej komórki</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Wszystkie (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuj plik</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuj plik</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Zawartość komórki</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Pokaż arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Ustaw kolor pierwszego planu komórki (komórek)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Ustawia kolor pierwszego planu komórki(ek) Arkusza kalkulacyjnego</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Ustaw kolor tła komórki(ek)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Ustawia kolor tła komórki(ek) Arkusza kalkulacyjnego</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Czarny</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Biały</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Czerwony</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Ciemny czerwony</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Zielony</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Ciemny zielony</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Niebieski</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Ciemny niebieski</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Turkusowy</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Ciemny turkusowy</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Purpurowy</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Ciemny purpurowy</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Żółty</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Ciemny żółty</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Szary</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Ciemny szary</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Jasnoszary</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Niestandardowe</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formularz</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Zawartość</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Nienazwany</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Wstaw wiersze</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Usuń wiersze</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Wstaw kolumny</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Usuwanie kolumn</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Właściwości...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Utwórz arkusz</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Utwórz nowy arkusz</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Wyrównaj w dół</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Wyrównaj do dołu zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Wyrównaj do środka</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Wyśrodkuj zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Wyrównaj do lewej</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Wyrównaj do lewej zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Wyrównaj do prawej</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Wyrównaj do prawej zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Wyrównaj w górę</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Wyrównaj w górę zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Wyśrodkuj w pionie</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Wyśrodkuj w pionie zawartość wybranych komórek</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuj arkusz</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuj arkusz do pliku CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuj arkusz</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuj zawartość pliku CSV do arkusza</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Scal komórki</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Scal wybrane komórki</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Ustaw alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Ustaw alias dla wybranej komórki</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Podziel komórkę</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Rozdziel uprzednio scalone komórki</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Pogrubienie</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Umieść tekst w zaznaczonych komórkach pogrubioną czcionką</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Kursywa</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Umieść tekst w zaznaczonych komórkach pochyłą czcionką</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Podkreślenie</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Podkreśl tekst w zaznaczonych komórkach</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Kolor użytkownika</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Scal komórki</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Podziel komórkę</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation>Wyrównaj komórkę do lewej</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation>Wyśrodkuj komórkę</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation>Wyrównaj komórkę do prawej</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation>Wyrównaj komórkę do góry</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation>Wyrównaj komórkę do dołu</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation>Wyśrodkuj komórkę w pionie</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation>Ustaw pogrubiony tekst</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation>Ustaw pochylony tekst</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation>Ustaw tekst podkreślony</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation>Utwórz Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation>Ustaw właściwości komórki</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation>Edytuj komórkę</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Wstaw wiersze</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Usuń wiersze</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Wstaw kolumny</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation>Wyczyść komórkę(i)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation>Ustawia kolor pierwszoplanowy</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation>Ustaw kolor tła</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Właściwości komórki</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Kolor</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekst</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Tło</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Wyrównanie</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Poziomo</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>W lewo</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Wyśrodkowane</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>W prawo</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Pionowo</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>W górę</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>W dół</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Styl</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Pogrubienie</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Kursywa</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Podkreślenie</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Wyświetl jednostkę</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Nazwa jednostki</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias dla tej komórki</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Wszystkie (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuj plik</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuj plik</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Pokaż arkusz</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Ustaw kolor komórki</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Ustawia kolor tła komórki(ek) Arkusza kalkulacyjnego</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Ustaw kolor tła komórki(ek)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Ustawia kolor tła komórki(ek) Arkusza kalkulacyjnego</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Arkusz kalkulacyjny nie obsługuje wyboru zakresu podczas wklejania.
Wybierz tylko jedną komórkę.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopiowanie i wklejanie nie powiodło się</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation>Określenie nazwy zawiera nieprawidłowe znaki!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Odniesienie do komórki według oznaczenia nazwy (alias), np.
Arkusz.mój_alias zamiast Arkusz.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Czarne</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Białe</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Czerwony</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Ciemny czerwony</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Zielony</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Ciemny zielony</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Niebieski</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Ciemny niebieski</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Turkusowy</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Ciemny turkusowy</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Purpurowy</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Ciemny purpurowy</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Żółty</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Ciemny żółty</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Szary</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Ciemny szary</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Jasnoszary</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Kolor użytkownika</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formularz</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation>&amp;Zawartość:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation>&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation>Odniesienie do komórki według oznaczenia nazwy (alias), np.
Arkusz.mój_alias zamiast Arkusz.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Bez nazwy</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Wstaw wiersze</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Usuń wiersze</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Wstaw kolumny</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Usuwanie kolumn</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Właściwości...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Arkusz kalkulacyjny</translation>
    </message>
  </context>
</TS>
